@@ -115,7 +115,7 @@ extern int                 g_soundCard2InDeviceNum;
 extern int                 g_soundCard2OutDeviceNum;
 extern int                 g_soundCard2SampleRate;
 
-// Voice Keyer Constants
+// Voice Keyer Constants 
 
 #define VK_SYNC_WAIT_TIME 5.0
 
@@ -134,6 +134,13 @@ extern int                 g_soundCard2SampleRate;
 #define VK_DT            3
 #define VK_SYNC          4
 
+// "Detect Sync" state machine states and constants
+
+#define DS_IDLE           0
+#define DS_SYNC_WAIT      1
+#define DS_UNSYNC_WAIT    2
+#define DS_SYNC_WAIT_TIME 5.0
+
 class MainFrame;
 
 //-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=--=-=-=-=
@@ -261,6 +268,7 @@ class MainApp : public wxApp
         wxRect              m_rTopWindow;
 
         int                 m_framesPerBuffer;
+        int                 m_fifoSize_ms;
 
         bool                loadConfig();
         bool                saveConfig();
@@ -293,8 +301,11 @@ class MainApp : public wxApp
         // 700 options
 
         bool       m_FreeDV700txClip;
+        bool       m_FreeDV700txBPF;
         bool       m_FreeDV700Combine;
-
+        int        m_FreeDV700Interleave;
+        bool       m_FreeDV700ManualUnSync;
+        
         // Noise simulation
 
         int        m_noise_snr;
@@ -313,6 +324,11 @@ class MainApp : public wxApp
         // Windows debug console
 
         bool       m_debug_console;
+        
+        // debugging 700D audio break up
+        
+        bool       m_txRxThreadHighPriority;
+        
     protected:
 };
 
@@ -437,7 +453,7 @@ class MainFrame : public TopFrame
 
         PaError                 m_rxErr;
         PaError                 m_txErr;
-        
+
         txRxThread*             m_txRxThread;
 
         bool                    OpenHamlibRig();
@@ -487,9 +503,17 @@ class MainFrame : public TopFrame
     int                     PollUDP();
     bool                    m_schedule_restore;
 
+    // Voice Keyer state machine
+    
     int                     vk_state;
     void VoiceKeyerProcessEvent(int vk_event);
 
+    // Detect Sync state machine
+    
+    int                     ds_state;
+    float                   ds_rx_time;
+    void DetectSyncProcessEvent(void);
+
     protected:
 
         void setsnrBeta(bool snrSlow);
@@ -545,7 +569,8 @@ class MainFrame : public TopFrame
 
         void OnCallSignReset( wxCommandEvent& event );
         void OnBerReset( wxCommandEvent& event );
-
+        void OnReSync( wxCommandEvent& event );
+ 
         //System Events
         void OnPaint(wxPaintEvent& event);
         void OnSize( wxSizeEvent& event );
@@ -678,4 +703,7 @@ void freq_shift_coh(COMP rx_fdm_fcorr[], COMP rx_fdm[], float foff, float Fs, CO
 
 int plugin_get_persistant(char name[], char value[]);
 
+void UDPSend(int port, char *buf, unsigned int n);
+void UDPInit(void);
+
 #endif //__FDMDV2_MAIN__
