@@ -103,13 +103,20 @@ class TopFrame : public wxFrame
         wxStaticText  *m_textErrors;
         wxStaticText  *m_textBER;
         wxStaticText  *m_textResyncs;
+        wxStaticText  *m_textClockOffset;
+        wxStaticText  *m_textFreqOffset;
+        wxStaticText  *m_textSyncMetric;
 
-        wxRadioButton *m_rbSync;
+        wxStaticText  *m_textSync;
+        wxStaticText  *m_textInterleaverSync;
+        wxButton      *m_BtnReSync;
+       
         wxRadioButton *m_rb1400old;
         wxRadioButton *m_rb1400;
         wxRadioButton *m_rb700;
         wxRadioButton *m_rb700b;
         wxRadioButton *m_rb700c;
+        wxRadioButton *m_rb700d;
         wxRadioButton *m_rb800xa;
         wxRadioButton *m_rb1600;
         wxRadioButton *m_rb2000;
@@ -172,6 +179,7 @@ class TopFrame : public wxFrame
 
         virtual void OnCallSignReset( wxCommandEvent& event ) { event.Skip(); }
         virtual void OnBerReset( wxCommandEvent& event ) { event.Skip(); }
+        virtual void OnReSync( wxCommandEvent& event ) { event.Skip(); }
 
     public:
         wxToggleButton* m_togRxID;
